<?php

namespace Drupal\Tests\acquia_optimize\Functional;

use Drupal\Tests\BrowserTestBase;

/**
 * Tests the Acquia Optimize button on content edit page.
 *
 * @group acquia_optimize
 */
class CreatePageContentTest extends BrowserTestBase {

  /**
   * {@inheritdoc}
   */
  protected static $modules = ['node', 'acquia_optimize'];

  /**
   * Theme to enable.
   *
   * @var string
   */
  protected $defaultTheme = 'stark';

  /**
   * A user with permissions to view Optimize button.
   *
   * @var \Drupal\user\Entity\User
   */
  protected $acquiaOptimizeUser;

  /**
   * A user without permissions to view Optimize button.
   *
   * @var \Drupal\user\Entity\User
   */
  protected $normalContentEditor;

  /**
   * An array of node objects.
   *
   * @var \Drupal\node\NodeInterface
   */
  protected $node;

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();
    $this->drupalCreateContentType(['type' => 'page']);
    $this->node = $this->drupalCreateNode(['type' => 'page']);
    $this->acquiaOptimizeUser = $this->createUser(['edit any page content', 'scan acquia optimize'], NULL, FALSE);
    $this->normalContentEditor = $this->createUser(['edit any page content'], NULL, FALSE);
  }

  /**
   * Tests that the button is visible to user with the correct permission.
   */
  public function testButtonIsVisibleToAdminUsers() {
    // Login as user with permission.
    $this->drupalLogin($this->acquiaOptimizeUser);
    $this->drupalGet("/node/{$this->node->id()}/edit");
    $this->assertSession()->pageTextContains('Acquia Optimize');
  }

  /**
   * Tests that the button isnt visible to users with the correct permissions.
   */
  public function testButtonIsNotVisibleToNormalUsers() {
    // Login as user without permission.
    $this->drupalLogin($this->normalContentEditor);
    $this->drupalGet("/node/{$this->node->id()}/edit");
    $this->assertSession()->pageTextNotContains('Acquia Optimize');
  }

}
