import React from 'react';
import { SeoWarningIcon, SeoCheckIcon, SeoIcon } from '../Icons';
import { SEO_ISSUES_MAPPING } from '../utils/constants';

const SEOSection = ({
  seoIssues,
  seoCount,
  toggleSection,
  expandedSections,
  detailedIssues,
  showSeoIssuesForCategory
}) => {
  if (!seoIssues || seoIssues.length === 0) {
    return null;
  }

  return (
    <div style={{
      borderBottom: '1px solid #eee',
      paddingBottom: '15px',
      marginBottom: '15px',
      width: '100%',
    }}>
      <div
        style={{
          display: 'flex',
          justifyContent: 'space-between',
          alignItems: 'center',
          padding: '15px 0',
          cursor: 'pointer',
          width: '100%',
        }}
        onClick={() => toggleSection('seo')}
      >
        <div style={{ display: 'flex', alignItems: 'center' }}>
          <SeoIcon />
          <h3 style={{ fontSize: '18px', margin: 0, fontWeight: '500' }}>SEO</h3>
        </div>

        <div style={{ display: 'flex', alignItems: 'center' }}>
          {seoCount > 0 ? (
            <>
              <SeoWarningIcon />
              <span style={{ fontSize: '20px', fontWeight: 'bold', color: '#cc0000' }}>{seoCount}</span>
            </>
          ) : (
            <>
               <SeoCheckIcon />
              <span style={{ fontSize: '20px', fontWeight: 'bold', color: '#00cc00' }}>0</span>
            </>
          )}

          <svg
            style={{
              width: '24px',
              height: '24px',
              marginLeft: '6px',
              transform: expandedSections.seo ? 'rotate(180deg)' : 'rotate(0deg)',
              transition: 'transform 0.3s ease'
            }}
            viewBox="0 0 24 24"
            fill="#333"
          >
            <path d="M7 10L12 15L17 10H7Z"/>
          </svg>
        </div>
      </div>

      {expandedSections.seo && seoIssues.length > 0 && (
        <div style={{ paddingLeft: '35px', width: '100%' }}>
          <div style={{ padding: '10px 0', width: '100%' }}>
            <div style={{ fontSize: '15px', fontWeight: '500', marginBottom: '8px', color: '#333' }}>SEO Opportunities</div>

            <div style={{ marginTop: '12px', width: '100%' }}>
              {/* Group SEO issues by impact level for display */}
              {(() => {
                // Map API classification_name to display categories
                const categoryMap = {
                  error: 'high',
                  warning: 'medium',
                  info: 'low',
                  technical: 'technical'
                };

                // Group issues by category
                const categorizedIssues = {
                  high: [],
                  medium: [],
                  low: [],
                  technical: []
                };

                // Count issues in each category
                seoIssues.forEach(issue => {
                  const category = categoryMap[issue.classification_name] || 'low';
                  categorizedIssues[category].push(issue);
                });

                // Define icons and labels for each category
                const categoryConfig = {
                  high: {
                    label: 'High impact SEO Opportunities',
                    icon: <path d="M16 6l2.29 2.29-4.88 4.88-4-4L2 16.59 3.41 18l6-6 4 4 6.3-6.29L22 12V6h-6z" />
                  },
                  medium: {
                    label: 'Medium impact SEO Opportunities',
                    icon: <path d="M16 6l2.29 2.29-4.88 4.88-4-4L2 16.59 3.41 18l6-6 4 4 6.3-6.29L22 12V6h-6z" />
                  },
                  low: {
                    label: 'Low impact SEO Opportunities',
                    icon: <path d="M6 16l-1.41-1.41 4.59-4.59 4 4L20 7.13l1.4 1.41L13.4 16z" />
                  },
                  technical: {
                    label: 'Technical SEO Opportunities',
                    icon: <path d="M15.5 1h-8C6.12 1 5 2.12 5 3.5v17C5 21.88 6.12 23 7.5 23h8c1.38 0 2.5-1.12 2.5-2.5v-17C18 2.12 16.88 1 15.5 1zm-4 21c-.83 0-1.5-.67-1.5-1.5s.67-1.5 1.5-1.5 1.5.67 1.5 1.5-.67 1.5-1.5 1.5zm4.5-4H7V4h9v14z" />
                  }
                };

                // Use our comprehensive SEO issues mapping

                return (
                  <>
                    {Object.keys(categorizedIssues).map(category => (
                      <div key={category}>
                        <div
                          style={{
                            display: 'flex',
                            justifyContent: 'space-between',
                            padding: '8px 0',
                            fontSize: '15px',
                            width: '100%',
                            cursor: categorizedIssues[category].length > 0 ? 'pointer' : 'default'
                          }}
                          onClick={categorizedIssues[category].length > 0 ? (e) => showSeoIssuesForCategory(category, e) : undefined}
                        >
                          <div style={{ display: 'flex', alignItems: 'center', color: '#555', pointerEvents: 'none' }}>
                            <svg style={{ width: '18px', height: '18px', marginRight: '8px', color: '#777' }} viewBox="0 0 24 24" fill="currentColor">
                              {categoryConfig[category].icon}
                            </svg>
                            {categoryConfig[category].label}
                          </div>
                          <div style={{ display: 'flex', alignItems: 'center', pointerEvents: 'none' }}>
                            <span>{categorizedIssues[category].length}</span>
                            {categorizedIssues[category].length > 0 && (
                              <svg
                                style={{
                                  width: '18px',
                                  height: '18px',
                                  marginLeft: '6px',
                                  transform: detailedIssues[category] ? 'rotate(90deg)' : 'none',
                                  transition: 'transform 0.3s ease'
                                }}
                                viewBox="0 0 24 24"
                                fill="#333"
                              >
                                <path d="M14 5l7 7-7 7V5z" />
                              </svg>
                            )}
                          </div>
                        </div>

                        {/* Show detailed issues when expanded */}
                        {detailedIssues[category] && categorizedIssues[category].length > 0 && (
                          <div style={{
                            backgroundColor: '#f9f9f9',
                            borderRadius: '4px',
                            padding: '15px',
                            marginTop: '5px',
                            marginBottom: '10px'
                          }}>
                            {categorizedIssues[category].map((issue, index) => (
                              <div key={index} style={{
                                marginBottom: index < categorizedIssues[category].length - 1 ? '15px' : '0',
                                paddingBottom: index < categorizedIssues[category].length - 1 ? '15px' : '0',
                                borderBottom: index < categorizedIssues[category].length - 1 ? '1px solid #eee' : 'none'
                              }}>
                                <div style={{ marginBottom: '5px' }}>
                                  <div style={{
                                    display: 'inline-block',
                                    padding: '4px 8px',
                                    backgroundColor:
                                      category === 'high' ? '#FFEBEE' :
                                      category === 'medium' ? '#FFF7D6' :
                                      category === 'low' ? '#E8F5E9' : '#E3F2FD',
                                    borderRadius: '4px',
                                    color:
                                      category === 'high' ? '#C62828' :
                                      category === 'medium' ? '#856404' :
                                      category === 'low' ? '#2E7D32' : '#1565C0',
                                    marginBottom: '8px',
                                    fontSize: '14px',
                                    fontWeight: '500'
                                  }}>
                                    {category.charAt(0).toUpperCase() + category.slice(1)}
                                  </div>
                                </div>
                                <div style={{ fontSize: '15px', fontWeight: '500', color: '#333', marginBottom: '5px' }}>
                                  {SEO_ISSUES_MAPPING[issue.name] || issue.name}
                                </div>
                                <div style={{ fontSize: '14px', color: '#555' }}>
                                  {issue.description || 'Addressing this issue will improve your search engine ranking.'}
                                </div>
                              </div>
                            ))}
                          </div>
                        )}
                      </div>
                    ))}
                  </>
                );
              })()}
            </div>
          </div>
        </div>
      )}
    </div>
  );
};

export default SEOSection;
